"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    rest_api_id: str,
    stage_name: str,
    deployment_id: str,
    description: str = None,
    cache_cluster_enabled: bool = None,
    cache_cluster_size: str = None,
    variables: Dict = None,
    documentation_version: str = None,
    canary_settings: Dict = None,
    tracing_enabled: bool = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new Stage resource that references a pre-existing Deployment for the API.

    Args:
        rest_api_id(str): [Required] The string identifier of the associated RestApi.
        stage_name(str): [Required] The name for the Stage resource. Stage names can only contain alphanumeric characters, hyphens, and underscores. Maximum length is 128 characters.
        deployment_id(str): [Required] The identifier of the Deployment resource for the Stage resource.
        description(str, optional): The description of the Stage resource. Defaults to None.
        cache_cluster_enabled(bool, optional): Whether cache clustering is enabled for the stage. Defaults to None.
        cache_cluster_size(str, optional): The stage's cache cluster size. Defaults to None.
        variables(Dict, optional): A map that defines the stage variables for the new Stage resource. Variable names can have alphanumeric and underscore characters, and the values must match [A-Za-z0-9-._~:/?#&=,]+. Defaults to None.
        documentation_version(str, optional): The version of the associated API documentation. Defaults to None.
        canary_settings(Dict, optional): The canary deployment settings of this stage. Defaults to None.
        tracing_enabled(bool, optional): Specifies whether active tracing with X-ray is enabled for the Stage. Defaults to None.
        tags(Dict, optional): The key-value map of strings. The valid character set is [a-zA-Z+-=._:/]. The tag key can be up to 128 characters and must not start with aws:. The tag value can be up to 256 characters. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.stage.init.create(
                ctx, rest_api_id=value, stage_name=value, deployment_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.stage.init.create rest_api_id=value, stage_name=value, deployment_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="create_stage",
        op_kwargs={
            "restApiId": rest_api_id,
            "stageName": stage_name,
            "deploymentId": deployment_id,
            "description": description,
            "cacheClusterEnabled": cache_cluster_enabled,
            "cacheClusterSize": cache_cluster_size,
            "variables": variables,
            "documentationVersion": documentation_version,
            "canarySettings": canary_settings,
            "tracingEnabled": tracing_enabled,
            "tags": tags,
        },
    )


async def delete(hub, ctx, rest_api_id: str, stage_name: str) -> None:
    r"""
    **Autogenerated function**

    Deletes a Stage resource.

    Args:
        rest_api_id(str): [Required] The string identifier of the associated RestApi.
        stage_name(str): [Required] The name of the Stage resource to delete.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.stage.init.delete(
                ctx, rest_api_id=value, stage_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.stage.init.delete rest_api_id=value, stage_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="delete_stage",
        op_kwargs={"restApiId": rest_api_id, "stageName": stage_name},
    )


async def get(hub, ctx, rest_api_id: str, stage_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about a Stage resource.

    Args:
        rest_api_id(str): [Required] The string identifier of the associated RestApi.
        stage_name(str): [Required] The name of the Stage resource to get information about.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.stage.init.get(
                ctx, rest_api_id=value, stage_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.stage.init.get rest_api_id=value, stage_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="get_stage",
        op_kwargs={"restApiId": rest_api_id, "stageName": stage_name},
    )


async def get_all(hub, ctx, rest_api_id: str, deployment_id: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about one or more Stage resources.

    Args:
        rest_api_id(str): [Required] The string identifier of the associated RestApi.
        deployment_id(str, optional): The stages' deployment identifiers. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.stage.init.get_all(ctx, rest_api_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.stage.init.get_all rest_api_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="get_stages",
        op_kwargs={"restApiId": rest_api_id, "deploymentId": deployment_id},
    )


async def update(
    hub, ctx, rest_api_id: str, stage_name: str, patch_operations: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Changes information about a Stage resource.

    Args:
        rest_api_id(str): [Required] The string identifier of the associated RestApi.
        stage_name(str): [Required] The name of the Stage resource to change information about.
        patch_operations(List, optional): A list of update operations to be applied to the specified resource and in the order specified in this list. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.stage.init.update(
                ctx, rest_api_id=value, stage_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.stage.init.update rest_api_id=value, stage_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="update_stage",
        op_kwargs={
            "restApiId": rest_api_id,
            "stageName": stage_name,
            "patchOperations": patch_operations,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def render(
    hub,
    ctx,
    task: Dict,
    role_arn: str,
    ui_template: Dict = None,
    human_task_ui_arn: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Renders the UI template so that you can preview the worker's experience.

    Args:
        ui_template(Dict, optional): A Template object containing the worker UI template to render. Defaults to None.
        task(Dict): A RenderableTask object containing a representative task to render.
        role_arn(str): The Amazon Resource Name (ARN) that has access to the S3 objects that are used by the template.
        human_task_ui_arn(str, optional): The HumanTaskUiArn of the worker UI that you want to render. Do not provide a HumanTaskUiArn if you use the UiTemplate parameter. See a list of available Human Ui Amazon Resource Names (ARNs) in UiConfig. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.ui_template.render(ctx, task=value, role_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.ui_template.render task=value, role_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="render_ui_template",
        op_kwargs={
            "UiTemplate": ui_template,
            "Task": task,
            "RoleArn": role_arn,
            "HumanTaskUiArn": human_task_ui_arn,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(hub, ctx, next_token: str = None, max_results: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Lists the calling account's dedicated origination numbers and their metadata. For more information about origination numbers, see Origination numbers in the Amazon SNS Developer Guide.

    Args:
        next_token(str, optional): Token that the previous ListOriginationNumbers request returns. Defaults to None.
        max_results(int, optional): The maximum number of origination numbers to return. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sns.origination_number.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sns.origination_number.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sns",
        operation="list_origination_numbers",
        op_kwargs={"NextToken": next_token, "MaxResults": max_results},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def modify(hub, ctx, backup_id: str, never_expires: bool) -> Dict:
    r"""
    **Autogenerated function**

    Modifies attributes for AWS CloudHSM backup.

    Args:
        backup_id(str): The identifier (ID) of the backup to modify. To find the ID of a backup, use the DescribeBackups operation.
        never_expires(bool): Specifies whether the service should exempt a backup from the retention policy for the cluster. True exempts a backup from the retention policy. False means the service applies the backup retention policy defined at the cluster.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudhsmv2.backup.attribute.modify(
                ctx, backup_id=value, never_expires=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudhsmv2.backup.attribute.modify backup_id=value, never_expires=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudhsmv2",
        operation="modify_backup_attributes",
        op_kwargs={"BackupId": backup_id, "NeverExpires": never_expires},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    replication_subnet_group_identifier: str,
    replication_subnet_group_description: str,
    subnet_ids: List,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a replication subnet group given a list of the subnet IDs in a VPC.

    Args:
        replication_subnet_group_identifier(str): The name for the replication subnet group. This value is stored as a lowercase string. Constraints: Must contain no more than 255 alphanumeric characters, periods, spaces, underscores, or hyphens. Must not be "default". Example: mySubnetgroup .
        replication_subnet_group_description(str): The description for the subnet group.
        subnet_ids(List): One or more subnet IDs to be assigned to the subnet group.
        tags(List, optional): One or more tags to be assigned to the subnet group. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dms.replication.subnet_group.create(
                ctx,
                replication_subnet_group_identifier=value,
                replication_subnet_group_description=value,
                subnet_ids=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dms.replication.subnet_group.create replication_subnet_group_identifier=value, replication_subnet_group_description=value, subnet_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dms",
        operation="create_replication_subnet_group",
        op_kwargs={
            "ReplicationSubnetGroupIdentifier": replication_subnet_group_identifier,
            "ReplicationSubnetGroupDescription": replication_subnet_group_description,
            "SubnetIds": subnet_ids,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, replication_subnet_group_identifier: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a subnet group.

    Args:
        replication_subnet_group_identifier(str): The subnet group name of the replication instance.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dms.replication.subnet_group.delete(
                ctx, replication_subnet_group_identifier=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dms.replication.subnet_group.delete replication_subnet_group_identifier=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dms",
        operation="delete_replication_subnet_group",
        op_kwargs={
            "ReplicationSubnetGroupIdentifier": replication_subnet_group_identifier
        },
    )


async def describe_all(
    hub, ctx, filters: List = None, max_records: int = None, marker: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about the replication subnet groups.

    Args:
        filters(List, optional): Filters applied to replication subnet groups. Valid filter names: replication-subnet-group-id. Defaults to None.
        max_records(int, optional):  The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that the remaining results can be retrieved.  Default: 100 Constraints: Minimum 20, maximum 100. Defaults to None.
        marker(str, optional):  An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dms.replication.subnet_group.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dms.replication.subnet_group.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dms",
        operation="describe_replication_subnet_groups",
        op_kwargs={"Filters": filters, "MaxRecords": max_records, "Marker": marker},
    )


async def modify(
    hub,
    ctx,
    replication_subnet_group_identifier: str,
    subnet_ids: List,
    replication_subnet_group_description: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Modifies the settings for the specified replication subnet group.

    Args:
        replication_subnet_group_identifier(str): The name of the replication instance subnet group.
        replication_subnet_group_description(str, optional): A description for the replication instance subnet group. Defaults to None.
        subnet_ids(List): A list of subnet IDs.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dms.replication.subnet_group.modify(
                ctx, replication_subnet_group_identifier=value, subnet_ids=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dms.replication.subnet_group.modify replication_subnet_group_identifier=value, subnet_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dms",
        operation="modify_replication_subnet_group",
        op_kwargs={
            "ReplicationSubnetGroupIdentifier": replication_subnet_group_identifier,
            "ReplicationSubnetGroupDescription": replication_subnet_group_description,
            "SubnetIds": subnet_ids,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe_all(
    hub,
    ctx,
    report_arn: str,
    next_token: str = None,
    max_results: int = None,
    filter_: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Returns a list of details about test cases for a report.

    Args:
        report_arn(str):  The ARN of the report for which test cases are returned. .
        next_token(str, optional):  During a previous call, the maximum number of items that can be returned is the value specified in maxResults. If there more items in the list, then a unique string called a nextToken is returned. To get the next batch of items in the list, call this operation again, adding the next token to the call. To get all of the items in the list, keep calling this operation with each subsequent next token that is returned, until no more next tokens are returned. . Defaults to None.
        max_results(int, optional):  The maximum number of paginated test cases returned per response. Use nextToken to iterate pages in the list of returned TestCase objects. The default value is 100. . Defaults to None.
        filter_(Dict, optional):  A TestCaseFilter object used to filter the returned reports. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codebuild.test_case.describe_all(ctx, report_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codebuild.test_case.describe_all report_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codebuild",
        operation="describe_test_cases",
        op_kwargs={
            "reportArn": report_arn,
            "nextToken": next_token,
            "maxResults": max_results,
            "filter": filter_,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def poll(
    hub, ctx, action_type_id: Dict, max_batch_size: int = None, query_param: Dict = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about any jobs for AWS CodePipeline to act on. PollForJobs is valid only for action types with "Custom" in the owner field. If the action type contains "AWS" or "ThirdParty" in the owner field, the PollForJobs action returns an error.  When this API is called, AWS CodePipeline returns temporary credentials for the S3 bucket used to store artifacts for the pipeline, if the action requires access to that S3 bucket for input or output artifacts. This API also returns any secret values defined for the action.

    Args:
        action_type_id(Dict): Represents information about an action type.
        max_batch_size(int, optional): The maximum number of jobs to return in a poll for jobs call. Defaults to None.
        query_param(Dict, optional): A map of property names and values. For an action type with no queryable properties, this value must be null or an empty map. For an action type with a queryable property, you must supply that property as a key in the map. Only jobs whose action configuration matches the mapped value are returned. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codepipeline.for_.job.poll(ctx, action_type_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codepipeline.for_.job.poll action_type_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codepipeline",
        operation="poll_for_jobs",
        op_kwargs={
            "actionTypeId": action_type_id,
            "maxBatchSize": max_batch_size,
            "queryParam": query_param,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(
    hub,
    ctx,
    index_id: str,
    group_id: str,
    data_source_id: str = None,
    ordering_id: int = None,
) -> None:
    r"""
    **Autogenerated function**

    Deletes a group so that all users and sub groups that belong to the group can no longer access documents only available to that group. For example, after deleting the group "Summer Interns", all interns who belonged to that group no longer see intern-only documents in their search results. If you want to delete or replace users or sub groups of a group, you need to use the PutPrincipalMapping operation. For example, if a user in the group "Engineering" leaves the engineering team and another user takes their place, you provide an updated list of users or sub groups that belong to the "Engineering" group when calling PutPrincipalMapping. You can update your internal list of users or sub groups and input this list when calling PutPrincipalMapping.

    Args:
        index_id(str): The identifier of the index you want to delete a group from.
        data_source_id(str, optional): The identifier of the data source you want to delete a group from. This is useful if a group is tied to multiple data sources and you want to delete a group from accessing documents in a certain data source. For example, the groups "Research", "Engineering", and "Sales and Marketing" are all tied to the company's documents stored in the data sources Confluence and Salesforce. You want to delete "Research" and "Engineering" groups from Salesforce, so that these groups cannot access customer-related documents stored in Salesforce. Only "Sales and Marketing" should access documents in the Salesforce data source. Defaults to None.
        group_id(str): The identifier of the group you want to delete.
        ordering_id(int, optional): The timestamp identifier you specify to ensure Amazon Kendra does not override the latest DELETE action with previous actions. The highest number ID, which is the ordering ID, is the latest action you want to process and apply on top of other actions with lower number IDs. This prevents previous actions with lower number IDs from possibly overriding the latest action. The ordering ID can be the UNIX time of the last update you made to a group members list. You would then provide this list when calling PutPrincipalMapping. This ensures your DELETE action for that updated group with the latest members list doesn't get overwritten by earlier DELETE actions for the same group which are yet to be processed. The default ordering ID is the current UNIX time in milliseconds that the action was received by Amazon Kendra. . Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kendra.principal_mapping.delete(
                ctx, index_id=value, group_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kendra.principal_mapping.delete index_id=value, group_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kendra",
        operation="delete_principal_mapping",
        op_kwargs={
            "IndexId": index_id,
            "DataSourceId": data_source_id,
            "GroupId": group_id,
            "OrderingId": ordering_id,
        },
    )


async def describe(
    hub, ctx, index_id: str, group_id: str, data_source_id: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the processing of PUT and DELETE actions for mapping users to their groups. This includes information on the status of actions currently processing or yet to be processed, when actions were last updated, when actions were received by Amazon Kendra, the latest action that should process and apply after other actions, and useful error messages if an action could not be processed.

    Args:
        index_id(str): The identifier of the index required to check the processing of PUT and DELETE actions for mapping users to their groups.
        data_source_id(str, optional): The identifier of the data source to check the processing of PUT and DELETE actions for mapping users to their groups. Defaults to None.
        group_id(str): The identifier of the group required to check the processing of PUT and DELETE actions for mapping users to their groups.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kendra.principal_mapping.describe(
                ctx, index_id=value, group_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kendra.principal_mapping.describe index_id=value, group_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kendra",
        operation="describe_principal_mapping",
        op_kwargs={
            "IndexId": index_id,
            "DataSourceId": data_source_id,
            "GroupId": group_id,
        },
    )


async def put(
    hub,
    ctx,
    index_id: str,
    group_id: str,
    group_members: Dict,
    data_source_id: str = None,
    ordering_id: int = None,
    role_arn: str = None,
) -> None:
    r"""
    **Autogenerated function**

    Maps users to their groups. You can also map sub groups to groups. For example, the group "Company Intellectual Property Teams" includes sub groups "Research" and "Engineering". These sub groups include their own list of users or people who work in these teams. Only users who work in research and engineering, and therefore belong in the intellectual property group, can see top-secret company documents in their search results.  You map users to their groups when you want to filter search results for different users based on their group’s access to documents. For more information on filtering search results for different users, see Filtering on user context. If more than five PUT actions for a group are currently processing, a validation exception is thrown.

    Args:
        index_id(str): The identifier of the index you want to map users to their groups.
        data_source_id(str, optional): The identifier of the data source you want to map users to their groups. This is useful if a group is tied to multiple data sources, but you only want the group to access documents of a certain data source. For example, the groups "Research", "Engineering", and "Sales and Marketing" are all tied to the company's documents stored in the data sources Confluence and Salesforce. However, "Sales and Marketing" team only needs access to customer-related documents stored in Salesforce. Defaults to None.
        group_id(str): The identifier of the group you want to map its users to.
        group_members(Dict): The list that contains your users or sub groups that belong the same group. For example, the group "Company" includes the user "CEO" and the sub groups "Research", "Engineering", and "Sales and Marketing". If you have more than 1000 users and/or sub groups for a single group, you need to provide the path to the S3 file that lists your users and sub groups for a group. Your sub groups can contain more than 1000 users, but the list of sub groups that belong to a group (and/or users) must be no more than 1000.
        ordering_id(int, optional): The timestamp identifier you specify to ensure Amazon Kendra does not override the latest PUT action with previous actions. The highest number ID, which is the ordering ID, is the latest action you want to process and apply on top of other actions with lower number IDs. This prevents previous actions with lower number IDs from possibly overriding the latest action. The ordering ID can be the UNIX time of the last update you made to a group members list. You would then provide this list when calling PutPrincipalMapping. This ensures your PUT action for that updated group with the latest members list doesn't get overwritten by earlier PUT actions for the same group which are yet to be processed. The default ordering ID is the current UNIX time in milliseconds that the action was received by Amazon Kendra. Defaults to None.
        role_arn(str, optional): The Amazon Resource Name (ARN) of a role that has access to the S3 file that contains your list of users or sub groups that belong to a group. For more information, see IAM roles for Amazon Kendra. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kendra.principal_mapping.put(
                ctx, index_id=value, group_id=value, group_members=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kendra.principal_mapping.put index_id=value, group_id=value, group_members=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kendra",
        operation="put_principal_mapping",
        op_kwargs={
            "IndexId": index_id,
            "DataSourceId": data_source_id,
            "GroupId": group_id,
            "GroupMembers": group_members,
            "OrderingId": ordering_id,
            "RoleArn": role_arn,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub, ctx, next_token: str = None, max_results: int = None, name_contains: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns bot information as follows:    If you provide the nameContains field, the response includes information for the $LATEST version of all bots whose name contains the specified string.   If you don't specify the nameContains field, the operation returns information about the $LATEST version of all of your bots.   This operation requires permission for the lex:GetBots action.

    Args:
        next_token(str, optional): A pagination token that fetches the next page of bots. If the response to this call is truncated, Amazon Lex returns a pagination token in the response. To fetch the next page of bots, specify the pagination token in the next request. . Defaults to None.
        max_results(int, optional): The maximum number of bots to return in the response that the request will return. The default is 10. Defaults to None.
        name_contains(str, optional): Substring to match in bot names. A bot will be returned if any part of its name matches the substring. For example, "xyz" matches both "xyzabc" and "abcxyz.". Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lex_model.bots.get(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lex_model.bots.get
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lex-models",
        operation="get_bots",
        op_kwargs={
            "nextToken": next_token,
            "maxResults": max_results,
            "nameContains": name_contains,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(hub, ctx, resource_name: str, tags: List) -> None:
    r"""
    **Autogenerated function**

    Adds tags to a cluster. A resource can have up to 50 tags. If you try to create more than 50 tags for a resource, you will receive an error and the attempt will fail. If you specify a key that already exists for the resource, the value for that key will be updated with the new value.

    Args:
        resource_name(str): The Amazon Resource Name (ARN) to which you want to add the tag or tags. For example, arn:aws:redshift:us-east-2:123456789:cluster:t1. .
        tags(List): One or more name/value pairs to add as tags to the specified resource. Each tag name is passed in with the parameter Key and the corresponding value is passed in with the parameter Value. The Key and Value parameters are separated by a comma (,). Separate multiple tags with a space. For example, --tags "Key"="owner","Value"="admin" "Key"="environment","Value"="test" "Key"="version","Value"="1.0". .
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.tags.create(ctx, resource_name=value, tags=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.tags.create resource_name=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="create_tags",
        op_kwargs={"ResourceName": resource_name, "Tags": tags},
    )


async def delete(hub, ctx, resource_name: str, tag_keys: List) -> None:
    r"""
    **Autogenerated function**

    Deletes tags from a resource. You must provide the ARN of the resource from which you want to delete the tag or tags.

    Args:
        resource_name(str): The Amazon Resource Name (ARN) from which you want to remove the tag or tags. For example, arn:aws:redshift:us-east-2:123456789:cluster:t1. .
        tag_keys(List): The tag key that you want to delete.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.tags.delete(ctx, resource_name=value, tag_keys=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.tags.delete resource_name=value, tag_keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="delete_tags",
        op_kwargs={"ResourceName": resource_name, "TagKeys": tag_keys},
    )


async def describe(
    hub,
    ctx,
    resource_name: str = None,
    resource_type: str = None,
    max_records: int = None,
    marker: str = None,
    tag_keys: List = None,
    tag_values: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of tags. You can return tags from a specific resource by specifying an ARN, or you can return all tags for a given type of resource, such as clusters, snapshots, and so on. The following are limitations for DescribeTags:    You cannot specify an ARN and a resource-type value together in the same request.   You cannot use the MaxRecords and Marker parameters together with the ARN parameter.   The MaxRecords parameter can be a range from 10 to 50 results to return in a request.   If you specify both tag keys and tag values in the same request, Amazon Redshift returns all resources that match any combination of the specified keys and values. For example, if you have owner and environment for tag keys, and admin and test for tag values, all resources that have any combination of those values are returned. If both tag keys and values are omitted from the request, resources are returned regardless of whether they have tag keys or values associated with them.

    Args:
        resource_name(str, optional): The Amazon Resource Name (ARN) for which you want to describe the tag or tags. For example, arn:aws:redshift:us-east-2:123456789:cluster:t1. . Defaults to None.
        resource_type(str, optional): The type of resource with which you want to view tags. Valid resource types are:    Cluster   CIDR/IP   EC2 security group   Snapshot   Cluster security group   Subnet group   HSM connection   HSM certificate   Parameter group   Snapshot copy grant   For more information about Amazon Redshift resource types and constructing ARNs, go to Specifying Policy Elements: Actions, Effects, Resources, and Principals in the Amazon Redshift Cluster Management Guide. . Defaults to None.
        max_records(int, optional): The maximum number or response records to return in each call. If the number of remaining response records exceeds the specified MaxRecords value, a value is returned in a marker field of the response. You can retrieve the next set of records by retrying the command with the returned marker value. . Defaults to None.
        marker(str, optional): A value that indicates the starting point for the next set of response records in a subsequent request. If a value is returned in a response, you can retrieve the next set of records by providing this returned marker value in the marker parameter and retrying the command. If the marker field is empty, all response records have been retrieved for the request. . Defaults to None.
        tag_keys(List, optional): A tag key or keys for which you want to return all matching resources that are associated with the specified key or keys. For example, suppose that you have resources tagged with keys called owner and environment. If you specify both of these tag keys in the request, Amazon Redshift returns a response with all resources that have either or both of these tag keys associated with them. Defaults to None.
        tag_values(List, optional): A tag value or values for which you want to return all matching resources that are associated with the specified value or values. For example, suppose that you have resources tagged with values called admin and test. If you specify both of these tag values in the request, Amazon Redshift returns a response with all resources that have either or both of these tag values associated with them. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.tags.describe(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.tags.describe
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="describe_tags",
        op_kwargs={
            "ResourceName": resource_name,
            "ResourceType": resource_type,
            "MaxRecords": max_records,
            "Marker": marker,
            "TagKeys": tag_keys,
            "TagValues": tag_values,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def deregister(hub, ctx, directory_id: str, topic_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Removes the specified directory as a publisher to the specified SNS topic.

    Args:
        directory_id(str): The Directory ID to remove as a publisher. This directory will no longer send messages to the specified SNS topic.
        topic_name(str): The name of the SNS topic from which to remove the directory as a publisher.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ds.event_topic.deregister(
                ctx, directory_id=value, topic_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ds.event_topic.deregister directory_id=value, topic_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ds",
        operation="deregister_event_topic",
        op_kwargs={"DirectoryId": directory_id, "TopicName": topic_name},
    )


async def describe_all(
    hub, ctx, directory_id: str = None, topic_names: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Obtains information about which SNS topics receive status messages from the specified directory. If no input parameters are provided, such as DirectoryId or TopicName, this request describes all of the associations in the account.

    Args:
        directory_id(str, optional): The Directory ID for which to get the list of associated SNS topics. If this member is null, associations for all Directory IDs are returned. Defaults to None.
        topic_names(List, optional): A list of SNS topic names for which to obtain the information. If this member is null, all associations for the specified Directory ID are returned. An empty list results in an InvalidParameterException being thrown. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ds.event_topic.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ds.event_topic.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ds",
        operation="describe_event_topics",
        op_kwargs={"DirectoryId": directory_id, "TopicNames": topic_names},
    )


async def register(hub, ctx, directory_id: str, topic_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Associates a directory with an SNS topic. This establishes the directory as a publisher to the specified SNS topic. You can then receive email or text (SMS) messages when the status of your directory changes. You get notified if your directory goes from an Active status to an Impaired or Inoperable status. You also receive a notification when the directory returns to an Active status.

    Args:
        directory_id(str): The Directory ID that will publish status messages to the SNS topic.
        topic_name(str): The SNS topic name to which the directory will publish status messages. This SNS topic must be in the same region as the specified Directory ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ds.event_topic.register(
                ctx, directory_id=value, topic_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ds.event_topic.register directory_id=value, topic_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ds",
        operation="register_event_topic",
        op_kwargs={"DirectoryId": directory_id, "TopicName": topic_name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(hub, ctx, account_id: str) -> None:
    r"""
    **Autogenerated function**

    Removes the PublicAccessBlock configuration for an account. For more information, see  Using Amazon S3 block public access. Related actions include:    GetPublicAccessBlock     PutPublicAccessBlock

    Args:
        account_id(str): The account ID for the account whose PublicAccessBlock configuration you want to remove.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3control.public_access_block.delete(ctx, account_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3control.public_access_block.delete account_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3control",
        operation="delete_public_access_block",
        op_kwargs={"AccountId": account_id},
    )


async def get(hub, ctx, account_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the PublicAccessBlock configuration for an account. For more information, see  Using Amazon S3 block public access. Related actions include:    DeletePublicAccessBlock     PutPublicAccessBlock

    Args:
        account_id(str): The account ID for the account whose PublicAccessBlock configuration you want to retrieve.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3control.public_access_block.get(ctx, account_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3control.public_access_block.get account_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3control",
        operation="get_public_access_block",
        op_kwargs={"AccountId": account_id},
    )


async def put(
    hub, ctx, public_access_block_configuration: Dict, account_id: str
) -> None:
    r"""
    **Autogenerated function**

    Creates or modifies the PublicAccessBlock configuration for an account. For more information, see  Using Amazon S3 block public access. Related actions include:    GetPublicAccessBlock     DeletePublicAccessBlock

    Args:
        public_access_block_configuration(Dict): The PublicAccessBlock configuration that you want to apply to the specified account.
        account_id(str): The account ID for the account whose PublicAccessBlock configuration you want to set.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3control.public_access_block.put(
                ctx, public_access_block_configuration=value, account_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3control.public_access_block.put public_access_block_configuration=value, account_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3control",
        operation="put_public_access_block",
        op_kwargs={
            "PublicAccessBlockConfiguration": public_access_block_configuration,
            "AccountId": account_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe_all(
    hub,
    ctx,
    search_query: str,
    authentication_token: str = None,
    organization_id: str = None,
    marker: str = None,
    limit: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the groups specified by the query. Groups are defined by the underlying Active Directory.

    Args:
        authentication_token(str, optional): Amazon WorkDocs authentication token. Not required when using AWS administrator credentials to access the API. Defaults to None.
        search_query(str): A query to describe groups by group name.
        organization_id(str, optional): The ID of the organization. Defaults to None.
        marker(str, optional): The marker for the next set of results. (You received this marker from a previous call.). Defaults to None.
        limit(int, optional): The maximum number of items to return with this call. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workdoc.group.describe_all(ctx, search_query=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workdoc.group.describe_all search_query=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workdocs",
        operation="describe_groups",
        op_kwargs={
            "AuthenticationToken": authentication_token,
            "SearchQuery": search_query,
            "OrganizationId": organization_id,
            "Marker": marker,
            "Limit": limit,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub,
    ctx,
    pull_request_id: str,
    repository_name: str = None,
    before_commit_id: str = None,
    after_commit_id: str = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns comments made on a pull request.  Reaction counts might include numbers from user identities who were deleted after the reaction was made. For a count of reactions from active identities, use GetCommentReactions.

    Args:
        pull_request_id(str): The system-generated ID of the pull request. To get this ID, use ListPullRequests.
        repository_name(str, optional): The name of the repository that contains the pull request. Defaults to None.
        before_commit_id(str, optional): The full commit ID of the commit in the destination branch that was the tip of the branch at the time the pull request was created. Defaults to None.
        after_commit_id(str, optional): The full commit ID of the commit in the source branch that was the tip of the branch at the time the comment was made. Defaults to None.
        next_token(str, optional): An enumeration token that, when provided in a request, returns the next batch of the results. Defaults to None.
        max_results(int, optional): A non-zero, non-negative integer used to limit the number of returned results. The default is 100 comments. You can return up to 500 comments with a single request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codecommit.comment.for_.pull_request.get(
                ctx, pull_request_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codecommit.comment.for_.pull_request.get pull_request_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codecommit",
        operation="get_comments_for_pull_request",
        op_kwargs={
            "pullRequestId": pull_request_id,
            "repositoryName": repository_name,
            "beforeCommitId": before_commit_id,
            "afterCommitId": after_commit_id,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )


async def post(
    hub,
    ctx,
    pull_request_id: str,
    repository_name: str,
    before_commit_id: str,
    after_commit_id: str,
    content: str,
    location: Dict = None,
    client_request_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Posts a comment on a pull request.

    Args:
        pull_request_id(str): The system-generated ID of the pull request. To get this ID, use ListPullRequests.
        repository_name(str): The name of the repository where you want to post a comment on a pull request.
        before_commit_id(str): The full commit ID of the commit in the destination branch that was the tip of the branch at the time the pull request was created.
        after_commit_id(str): The full commit ID of the commit in the source branch that is the current tip of the branch for the pull request when you post the comment.
        location(Dict, optional): The location of the change where you want to post your comment. If no location is provided, the comment is posted as a general comment on the pull request difference between the before commit ID and the after commit ID. Defaults to None.
        content(str): The content of your comment on the change.
        client_request_token(str, optional): A unique, client-generated idempotency token that, when provided in a request, ensures the request cannot be repeated with a changed parameter. If a request is received with the same parameters and a token is included, the request returns information about the initial request that used that token. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codecommit.comment.for_.pull_request.post(
                ctx,
                pull_request_id=value,
                repository_name=value,
                before_commit_id=value,
                after_commit_id=value,
                content=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codecommit.comment.for_.pull_request.post pull_request_id=value, repository_name=value, before_commit_id=value, after_commit_id=value, content=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codecommit",
        operation="post_comment_for_pull_request",
        op_kwargs={
            "pullRequestId": pull_request_id,
            "repositoryName": repository_name,
            "beforeCommitId": before_commit_id,
            "afterCommitId": after_commit_id,
            "location": location,
            "content": content,
            "clientRequestToken": client_request_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(hub, ctx, reservation_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Delete an expired reservation.

    Args:
        reservation_id(str): Unique reservation ID, e.g. '1234567'.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.medialive.reservation.delete(ctx, reservation_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.medialive.reservation.delete reservation_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="medialive",
        operation="delete_reservation",
        op_kwargs={"ReservationId": reservation_id},
    )


async def describe(hub, ctx, reservation_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Get details for a reservation.

    Args:
        reservation_id(str): Unique reservation ID, e.g. '1234567'.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.medialive.reservation.describe(ctx, reservation_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.medialive.reservation.describe reservation_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="medialive",
        operation="describe_reservation",
        op_kwargs={"ReservationId": reservation_id},
    )


async def list_all(
    hub,
    ctx,
    channel_class: str = None,
    codec: str = None,
    max_results: int = None,
    maximum_bitrate: str = None,
    maximum_framerate: str = None,
    next_token: str = None,
    resolution: str = None,
    resource_type: str = None,
    special_feature: str = None,
    video_quality: str = None,
) -> Dict:
    r"""
        **Autogenerated function**

        List purchased reservations.

        Args:
            channel_class(str, optional): Filter by channel class, 'STANDARD' or 'SINGLE_PIPELINE'
    . Defaults to None.
            codec(str, optional): Filter by codec, 'AVC', 'HEVC', 'MPEG2', 'AUDIO', or 'LINK'. Defaults to None.
            max_results(int, optional): Placeholder documentation for MaxResults. Defaults to None.
            maximum_bitrate(str, optional): Filter by bitrate, 'MAX_10_MBPS', 'MAX_20_MBPS', or 'MAX_50_MBPS'
    . Defaults to None.
            maximum_framerate(str, optional): Filter by framerate, 'MAX_30_FPS' or 'MAX_60_FPS'. Defaults to None.
            next_token(str, optional): Placeholder documentation for __string. Defaults to None.
            resolution(str, optional): Filter by resolution, 'SD', 'HD', 'FHD', or 'UHD'. Defaults to None.
            resource_type(str, optional): Filter by resource type, 'INPUT', 'OUTPUT', 'MULTIPLEX', or 'CHANNEL'. Defaults to None.
            special_feature(str, optional): Filter by special feature, 'ADVANCED_AUDIO' or 'AUDIO_NORMALIZATION'
    . Defaults to None.
            video_quality(str, optional): Filter by video quality, 'STANDARD', 'ENHANCED', or 'PREMIUM'
    . Defaults to None.

        Returns:
            Dict

        Examples:
            Call from code:

            .. code-block:: python

                await hub.exec.aws_auto.medialive.reservation.list_all(ctx)

            Call from CLI:

            .. code-block:: bash

                $ idem exec aws_auto.medialive.reservation.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="medialive",
        operation="list_reservations",
        op_kwargs={
            "ChannelClass": channel_class,
            "Codec": codec,
            "MaxResults": max_results,
            "MaximumBitrate": maximum_bitrate,
            "MaximumFramerate": maximum_framerate,
            "NextToken": next_token,
            "Resolution": resolution,
            "ResourceType": resource_type,
            "SpecialFeature": special_feature,
            "VideoQuality": video_quality,
        },
    )


async def update(hub, ctx, reservation_id: str, name: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Update reservation.

    Args:
        name(str, optional): Name of the reservation. Defaults to None.
        reservation_id(str): Unique reservation ID, e.g. '1234567'.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.medialive.reservation.update(ctx, reservation_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.medialive.reservation.update reservation_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="medialive",
        operation="update_reservation",
        op_kwargs={"Name": name, "ReservationId": reservation_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"global_": "global"}


async def global_(hub, ctx, access_token: str) -> Dict:
    r"""
    **Autogenerated function**

    Signs out users from all devices. It also invalidates all refresh tokens issued to a user. The user's current access and Id tokens remain valid until their expiry. Access and Id tokens expire one hour after they are issued.

    Args:
        access_token(str): The access token.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_idp.sign.out.global(ctx, access_token=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_idp.sign.out.global access_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-idp",
        operation="global_sign_out",
        op_kwargs={"AccessToken": access_token},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def deregister(hub, ctx, instance_name: str) -> None:
    r"""
    **Autogenerated function**

    Deregisters an on-premises instance.

    Args:
        instance_name(str): The name of the on-premises instance to deregister.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codedeploy.on_premise_instance.deregister(
                ctx, instance_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codedeploy.on_premise_instance.deregister instance_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codedeploy",
        operation="deregister_on_premises_instance",
        op_kwargs={"instanceName": instance_name},
    )


async def get(hub, ctx, instance_name: str) -> Dict:
    r"""
    **Autogenerated function**

     Gets information about an on-premises instance.

    Args:
        instance_name(str):  The name of the on-premises instance about which to get information. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codedeploy.on_premise_instance.get(ctx, instance_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codedeploy.on_premise_instance.get instance_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codedeploy",
        operation="get_on_premises_instance",
        op_kwargs={"instanceName": instance_name},
    )


async def list_all(
    hub,
    ctx,
    registration_status: str = None,
    tag_filters: List = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets a list of names for one or more on-premises instances. Unless otherwise specified, both registered and deregistered on-premises instance names are listed. To list only registered or deregistered on-premises instance names, use the registration status parameter.

    Args:
        registration_status(str, optional): The registration status of the on-premises instances:    Deregistered: Include deregistered on-premises instances in the resulting list.    Registered: Include registered on-premises instances in the resulting list.  . Defaults to None.
        tag_filters(List, optional): The on-premises instance tags that are used to restrict the on-premises instance names returned. Defaults to None.
        next_token(str, optional): An identifier returned from the previous list on-premises instances call. It can be used to return the next set of on-premises instances in the list. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codedeploy.on_premise_instance.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codedeploy.on_premise_instance.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codedeploy",
        operation="list_on_premises_instances",
        op_kwargs={
            "registrationStatus": registration_status,
            "tagFilters": tag_filters,
            "nextToken": next_token,
        },
    )


async def register(
    hub, ctx, instance_name: str, iam_session_arn: str = None, iam_user_arn: str = None
) -> None:
    r"""
    **Autogenerated function**

    Registers an on-premises instance.  Only one IAM ARN (an IAM session ARN or IAM user ARN) is supported in the request. You cannot use both.

    Args:
        instance_name(str): The name of the on-premises instance to register.
        iam_session_arn(str, optional): The ARN of the IAM session to associate with the on-premises instance. Defaults to None.
        iam_user_arn(str, optional): The ARN of the IAM user to associate with the on-premises instance. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codedeploy.on_premise_instance.register(
                ctx, instance_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codedeploy.on_premise_instance.register instance_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codedeploy",
        operation="register_on_premises_instance",
        op_kwargs={
            "instanceName": instance_name,
            "iamSessionArn": iam_session_arn,
            "iamUserArn": iam_user_arn,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__virtualname__ = "type"


async def create(
    hub,
    ctx,
    name: str,
    description: str,
    qualification_type_status: str,
    keywords: str = None,
    retry_delay_in_seconds: int = None,
    test: str = None,
    answer_key: str = None,
    test_duration_in_seconds: int = None,
    auto_granted: bool = None,
    auto_granted_value: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

     The CreateQualificationType operation creates a new Qualification type, which is represented by a QualificationType data structure.

    Args:
        name(str):  The name you give to the Qualification type. The type name is used to represent the Qualification to Workers, and to find the type using a Qualification type search. It must be unique across all of your Qualification types.
        keywords(str, optional): One or more words or phrases that describe the Qualification type, separated by commas. The keywords of a type make the type easier to find during a search. Defaults to None.
        description(str): A long description for the Qualification type. On the Amazon Mechanical Turk website, the long description is displayed when a Worker examines a Qualification type.
        qualification_type_status(str): The initial status of the Qualification type. Constraints: Valid values are: Active | Inactive.
        retry_delay_in_seconds(int, optional): The number of seconds that a Worker must wait after requesting a Qualification of the Qualification type before the worker can retry the Qualification request. Constraints: None. If not specified, retries are disabled and Workers can request a Qualification of this type only once, even if the Worker has not been granted the Qualification. It is not possible to disable retries for a Qualification type after it has been created with retries enabled. If you want to disable retries, you must delete existing retry-enabled Qualification type and then create a new Qualification type with retries disabled. Defaults to None.
        test(str, optional):  The questions for the Qualification test a Worker must answer correctly to obtain a Qualification of this type. If this parameter is specified, TestDurationInSeconds must also be specified.  Constraints: Must not be longer than 65535 bytes. Must be a QuestionForm data structure. This parameter cannot be specified if AutoGranted is true. Constraints: None. If not specified, the Worker may request the Qualification without answering any questions. Defaults to None.
        answer_key(str, optional): The answers to the Qualification test specified in the Test parameter, in the form of an AnswerKey data structure. Constraints: Must not be longer than 65535 bytes. Constraints: None. If not specified, you must process Qualification requests manually. Defaults to None.
        test_duration_in_seconds(int, optional): The number of seconds the Worker has to complete the Qualification test, starting from the time the Worker requests the Qualification. Defaults to None.
        auto_granted(bool, optional): Specifies whether requests for the Qualification type are granted immediately, without prompting the Worker with a Qualification test. Constraints: If the Test parameter is specified, this parameter cannot be true. Defaults to None.
        auto_granted_value(int, optional): The Qualification value to use for automatically granted Qualifications. This parameter is used only if the AutoGranted parameter is true. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mturk.qualification.type_.create(
                ctx, name=value, description=value, qualification_type_status=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mturk.qualification.type.create name=value, description=value, qualification_type_status=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mturk",
        operation="create_qualification_type",
        op_kwargs={
            "Name": name,
            "Keywords": keywords,
            "Description": description,
            "QualificationTypeStatus": qualification_type_status,
            "RetryDelayInSeconds": retry_delay_in_seconds,
            "Test": test,
            "AnswerKey": answer_key,
            "TestDurationInSeconds": test_duration_in_seconds,
            "AutoGranted": auto_granted,
            "AutoGrantedValue": auto_granted_value,
        },
    )


async def delete(hub, ctx, qualification_type_id: str) -> Dict:
    r"""
    **Autogenerated function**

     The DeleteQualificationType deletes a Qualification type and deletes any HIT types that are associated with the Qualification type.  This operation does not revoke Qualifications already assigned to Workers because the Qualifications might be needed for active HITs. If there are any pending requests for the Qualification type, Amazon Mechanical Turk rejects those requests. After you delete a Qualification type, you can no longer use it to create HITs or HIT types.  DeleteQualificationType must wait for all the HITs that use the deleted Qualification type to be deleted before completing. It may take up to 48 hours before DeleteQualificationType completes and the unique name of the Qualification type is available for reuse with CreateQualificationType.

    Args:
        qualification_type_id(str): The ID of the QualificationType to dispose.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mturk.qualification.type_.delete(
                ctx, qualification_type_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mturk.qualification.type.delete qualification_type_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mturk",
        operation="delete_qualification_type",
        op_kwargs={"QualificationTypeId": qualification_type_id},
    )


async def get(hub, ctx, qualification_type_id: str) -> Dict:
    r"""
    **Autogenerated function**

     The GetQualificationTypeoperation retrieves information about a Qualification type using its ID.

    Args:
        qualification_type_id(str): The ID of the QualificationType.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mturk.qualification.type_.get(ctx, qualification_type_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mturk.qualification.type.get qualification_type_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mturk",
        operation="get_qualification_type",
        op_kwargs={"QualificationTypeId": qualification_type_id},
    )


async def list_all(
    hub,
    ctx,
    must_be_requestable: bool,
    query: str = None,
    must_be_owned_by_caller: bool = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

     The ListQualificationTypes operation returns a list of Qualification types, filtered by an optional search term.

    Args:
        query(str, optional):  A text query against all of the searchable attributes of Qualification types. . Defaults to None.
        must_be_requestable(bool): Specifies that only Qualification types that a user can request through the Amazon Mechanical Turk web site, such as by taking a Qualification test, are returned as results of the search. Some Qualification types, such as those assigned automatically by the system, cannot be requested directly by users. If false, all Qualification types, including those managed by the system, are considered. Valid values are True | False. .
        must_be_owned_by_caller(bool, optional):  Specifies that only Qualification types that the Requester created are returned. If false, the operation returns all Qualification types. . Defaults to None.
        next_token(str, optional): If the previous response was incomplete (because there is more data to retrieve), Amazon Mechanical Turk returns a pagination token in the response. You can use this pagination token to retrieve the next set of results. . Defaults to None.
        max_results(int, optional):  The maximum number of results to return in a single call. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mturk.qualification.type_.list_all(
                ctx, must_be_requestable=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mturk.qualification.type.list_all must_be_requestable=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mturk",
        operation="list_qualification_types",
        op_kwargs={
            "Query": query,
            "MustBeRequestable": must_be_requestable,
            "MustBeOwnedByCaller": must_be_owned_by_caller,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )


async def update(
    hub,
    ctx,
    qualification_type_id: str,
    description: str = None,
    qualification_type_status: str = None,
    test: str = None,
    answer_key: str = None,
    test_duration_in_seconds: int = None,
    retry_delay_in_seconds: int = None,
    auto_granted: bool = None,
    auto_granted_value: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

     The UpdateQualificationType operation modifies the attributes of an existing Qualification type, which is represented by a QualificationType data structure. Only the owner of a Qualification type can modify its attributes.   Most attributes of a Qualification type can be changed after the type has been created. However, the Name and Keywords fields cannot be modified. The RetryDelayInSeconds parameter can be modified or added to change the delay or to enable retries, but RetryDelayInSeconds cannot be used to disable retries.   You can use this operation to update the test for a Qualification type. The test is updated based on the values specified for the Test, TestDurationInSeconds and AnswerKey parameters. All three parameters specify the updated test. If you are updating the test for a type, you must specify the Test and TestDurationInSeconds parameters. The AnswerKey parameter is optional; omitting it specifies that the updated test does not have an answer key.   If you omit the Test parameter, the test for the Qualification type is unchanged. There is no way to remove a test from a Qualification type that has one. If the type already has a test, you cannot update it to be AutoGranted. If the Qualification type does not have a test and one is provided by an update, the type will henceforth have a test.   If you want to update the test duration or answer key for an existing test without changing the questions, you must specify a Test parameter with the original questions, along with the updated values.   If you provide an updated Test but no AnswerKey, the new test will not have an answer key. Requests for such Qualifications must be granted manually.   You can also update the AutoGranted and AutoGrantedValue attributes of the Qualification type.

    Args:
        qualification_type_id(str): The ID of the Qualification type to update.
        description(str, optional): The new description of the Qualification type. Defaults to None.
        qualification_type_status(str, optional): The new status of the Qualification type - Active | Inactive. Defaults to None.
        test(str, optional): The questions for the Qualification test a Worker must answer correctly to obtain a Qualification of this type. If this parameter is specified, TestDurationInSeconds must also be specified. Constraints: Must not be longer than 65535 bytes. Must be a QuestionForm data structure. This parameter cannot be specified if AutoGranted is true. Constraints: None. If not specified, the Worker may request the Qualification without answering any questions. Defaults to None.
        answer_key(str, optional): The answers to the Qualification test specified in the Test parameter, in the form of an AnswerKey data structure. Defaults to None.
        test_duration_in_seconds(int, optional): The number of seconds the Worker has to complete the Qualification test, starting from the time the Worker requests the Qualification. Defaults to None.
        retry_delay_in_seconds(int, optional): The amount of time, in seconds, that Workers must wait after requesting a Qualification of the specified Qualification type before they can retry the Qualification request. It is not possible to disable retries for a Qualification type after it has been created with retries enabled. If you want to disable retries, you must dispose of the existing retry-enabled Qualification type using DisposeQualificationType and then create a new Qualification type with retries disabled using CreateQualificationType. Defaults to None.
        auto_granted(bool, optional): Specifies whether requests for the Qualification type are granted immediately, without prompting the Worker with a Qualification test. Constraints: If the Test parameter is specified, this parameter cannot be true. Defaults to None.
        auto_granted_value(int, optional): The Qualification value to use for automatically granted Qualifications. This parameter is used only if the AutoGranted parameter is true. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mturk.qualification.type_.update(
                ctx, qualification_type_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mturk.qualification.type.update qualification_type_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mturk",
        operation="update_qualification_type",
        op_kwargs={
            "QualificationTypeId": qualification_type_id,
            "Description": description,
            "QualificationTypeStatus": qualification_type_status,
            "Test": test,
            "AnswerKey": answer_key,
            "TestDurationInSeconds": test_duration_in_seconds,
            "RetryDelayInSeconds": retry_delay_in_seconds,
            "AutoGranted": auto_granted,
            "AutoGrantedValue": auto_granted_value,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(hub, ctx, bucket: str, expected_bucket_owner: str = None) -> None:
    r"""
    **Autogenerated function**

    Removes the PublicAccessBlock configuration for an Amazon S3 bucket. To use this operation, you must have the s3:PutBucketPublicAccessBlock permission. For more information about permissions, see Permissions Related to Bucket Subresource Operations and Managing Access Permissions to Your Amazon S3 Resources. The following operations are related to DeletePublicAccessBlock:    Using Amazon S3 Block Public Access     GetPublicAccessBlock     PutPublicAccessBlock     GetBucketPolicyStatus

    Args:
        bucket(str): The Amazon S3 bucket whose PublicAccessBlock configuration you want to delete. .
        expected_bucket_owner(str, optional): The account ID of the expected bucket owner. If the bucket is owned by a different account, the request will fail with an HTTP 403 (Access Denied) error. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3.public_access_block.delete(ctx, bucket=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3.public_access_block.delete bucket=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3",
        operation="delete_public_access_block",
        op_kwargs={"Bucket": bucket, "ExpectedBucketOwner": expected_bucket_owner},
    )


async def get(hub, ctx, bucket: str, expected_bucket_owner: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the PublicAccessBlock configuration for an Amazon S3 bucket. To use this operation, you must have the s3:GetBucketPublicAccessBlock permission. For more information about Amazon S3 permissions, see Specifying Permissions in a Policy.  When Amazon S3 evaluates the PublicAccessBlock configuration for a bucket or an object, it checks the PublicAccessBlock configuration for both the bucket (or the bucket that contains the object) and the bucket owner's account. If the PublicAccessBlock settings are different between the bucket and the account, Amazon S3 uses the most restrictive combination of the bucket-level and account-level settings.  For more information about when Amazon S3 considers a bucket or an object public, see The Meaning of "Public". The following operations are related to GetPublicAccessBlock:    Using Amazon S3 Block Public Access     PutPublicAccessBlock     GetPublicAccessBlock     DeletePublicAccessBlock

    Args:
        bucket(str): The name of the Amazon S3 bucket whose PublicAccessBlock configuration you want to retrieve. .
        expected_bucket_owner(str, optional): The account ID of the expected bucket owner. If the bucket is owned by a different account, the request will fail with an HTTP 403 (Access Denied) error. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3.public_access_block.get(ctx, bucket=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3.public_access_block.get bucket=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3",
        operation="get_public_access_block",
        op_kwargs={"Bucket": bucket, "ExpectedBucketOwner": expected_bucket_owner},
    )


async def put(
    hub,
    ctx,
    bucket: str,
    public_access_block_configuration: Dict,
    content_md5: str = None,
    expected_bucket_owner: str = None,
) -> None:
    r"""
    **Autogenerated function**

    Creates or modifies the PublicAccessBlock configuration for an Amazon S3 bucket. To use this operation, you must have the s3:PutBucketPublicAccessBlock permission. For more information about Amazon S3 permissions, see Specifying Permissions in a Policy.  When Amazon S3 evaluates the PublicAccessBlock configuration for a bucket or an object, it checks the PublicAccessBlock configuration for both the bucket (or the bucket that contains the object) and the bucket owner's account. If the PublicAccessBlock configurations are different between the bucket and the account, Amazon S3 uses the most restrictive combination of the bucket-level and account-level settings.  For more information about when Amazon S3 considers a bucket or an object public, see The Meaning of "Public".  Related Resources     GetPublicAccessBlock     DeletePublicAccessBlock     GetBucketPolicyStatus     Using Amazon S3 Block Public Access

    Args:
        bucket(str): The name of the Amazon S3 bucket whose PublicAccessBlock configuration you want to set.
        content_md5(str, optional): The MD5 hash of the PutPublicAccessBlock request body.  For requests made using the AWS Command Line Interface (CLI) or AWS SDKs, this field is calculated automatically. Defaults to None.
        public_access_block_configuration(Dict): The PublicAccessBlock configuration that you want to apply to this Amazon S3 bucket. You can enable the configuration options in any combination. For more information about when Amazon S3 considers a bucket or object public, see The Meaning of "Public" in the Amazon S3 User Guide.
        expected_bucket_owner(str, optional): The account ID of the expected bucket owner. If the bucket is owned by a different account, the request will fail with an HTTP 403 (Access Denied) error. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3.public_access_block.put(
                ctx, bucket=value, public_access_block_configuration=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3.public_access_block.put bucket=value, public_access_block_configuration=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3",
        operation="put_public_access_block",
        op_kwargs={
            "Bucket": bucket,
            "ContentMD5": content_md5,
            "PublicAccessBlockConfiguration": public_access_block_configuration,
            "ExpectedBucketOwner": expected_bucket_owner,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def promote(hub, ctx, db_cluster_identifier: str) -> Dict:
    r"""
    **Autogenerated function**

    Not supported.

    Args:
        db_cluster_identifier(str): Not supported.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.neptune.read_replica_db_cluster.promote(
                ctx, db_cluster_identifier=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.neptune.read_replica_db_cluster.promote db_cluster_identifier=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="neptune",
        operation="promote_read_replica_db_cluster",
        op_kwargs={"DBClusterIdentifier": db_cluster_identifier},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(
    hub,
    ctx,
    end_time: str,
    profiling_group_name: str,
    start_time: str,
    daily_reports_only: bool = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    List the available reports for a given profiling group and time range.

    Args:
        daily_reports_only(bool, optional): A Boolean value indicating whether to only return reports from daily profiles. If set to True, only analysis data from daily profiles is returned. If set to False, analysis data is returned from smaller time windows (for example, one hour). Defaults to None.
        end_time(str):  The end time of the profile to get analysis data about. You must specify startTime and endTime. This is specified using the ISO 8601 format. For example, 2020-06-01T13:15:02.001Z represents 1 millisecond past June 1, 2020 1:15:02 PM UTC. .
        max_results(int, optional): The maximum number of report results returned by ListFindingsReports in paginated output. When this parameter is used, ListFindingsReports only returns maxResults results in a single page along with a nextToken response element. The remaining results of the initial request can be seen by sending another ListFindingsReports request with the returned nextToken value. Defaults to None.
        next_token(str, optional): The nextToken value returned from a previous paginated ListFindingsReportsRequest request where maxResults was used and the results exceeded the value of that parameter. Pagination continues from the end of the previous results that returned the nextToken value.   This token should be treated as an opaque identifier that is only used to retrieve the next items in a list and not for other programmatic purposes. . Defaults to None.
        profiling_group_name(str): The name of the profiling group from which to search for analysis data.
        start_time(str):  The start time of the profile to get analysis data about. You must specify startTime and endTime. This is specified using the ISO 8601 format. For example, 2020-06-01T13:15:02.001Z represents 1 millisecond past June 1, 2020 1:15:02 PM UTC. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codeguruprofiler.finding_report.init.list_all(
                ctx, end_time=value, profiling_group_name=value, start_time=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codeguruprofiler.finding_report.init.list_all end_time=value, profiling_group_name=value, start_time=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codeguruprofiler",
        operation="list_findings_reports",
        op_kwargs={
            "dailyReportsOnly": daily_reports_only,
            "endTime": end_time,
            "maxResults": max_results,
            "nextToken": next_token,
            "profilingGroupName": profiling_group_name,
            "startTime": start_time,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def start(hub, ctx, app_id: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Starts replicating the specified application by creating replication jobs for each server in the application.

    Args:
        app_id(str, optional): The ID of the application. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sms.app.replication.init.start(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sms.app.replication.init.start
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sms",
        operation="start_app_replication",
        op_kwargs={"appId": app_id},
    )


async def stop(hub, ctx, app_id: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Stops replicating the specified application by deleting the replication job for each server in the application.

    Args:
        app_id(str, optional): The ID of the application. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sms.app.replication.init.stop(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sms.app.replication.init.stop
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sms",
        operation="stop_app_replication",
        op_kwargs={"appId": app_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__func_alias__ = {"import_": "import"}


async def delete(hub, ctx, certificate_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified certificate.

    Args:
        certificate_arn(str): The Amazon Resource Name (ARN) of the deleted certificate.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dms.certificate.delete(ctx, certificate_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dms.certificate.delete certificate_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dms",
        operation="delete_certificate",
        op_kwargs={"CertificateArn": certificate_arn},
    )


async def describe_all(
    hub, ctx, filters: List = None, max_records: int = None, marker: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Provides a description of the certificate.

    Args:
        filters(List, optional): Filters applied to the certificates described in the form of key-value pairs. Defaults to None.
        max_records(int, optional):  The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that the remaining results can be retrieved.  Default: 10. Defaults to None.
        marker(str, optional):  An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dms.certificate.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dms.certificate.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dms",
        operation="describe_certificates",
        op_kwargs={"Filters": filters, "MaxRecords": max_records, "Marker": marker},
    )


async def import_(
    hub,
    ctx,
    certificate_identifier: str,
    certificate_pem: str = None,
    certificate_wallet: bytes = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Uploads the specified certificate.

    Args:
        certificate_identifier(str): A customer-assigned name for the certificate. Identifiers must begin with a letter and must contain only ASCII letters, digits, and hyphens. They can't end with a hyphen or contain two consecutive hyphens.
        certificate_pem(str, optional): The contents of a .pem file, which contains an X.509 certificate. Defaults to None.
        certificate_wallet(bytes, optional): The location of an imported Oracle Wallet certificate for use with SSL. Provide the name of a .sso file using the fileb:// prefix. You can't provide the certificate inline. . Defaults to None.
        tags(List, optional): The tags associated with the certificate. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dms.certificate.import(ctx, certificate_identifier=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dms.certificate.import certificate_identifier=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dms",
        operation="import_certificate",
        op_kwargs={
            "CertificateIdentifier": certificate_identifier,
            "CertificatePem": certificate_pem,
            "CertificateWallet": certificate_wallet,
            "Tags": tags,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    creator_request_id: str,
    firewall_rule_group_id: str,
    firewall_domain_list_id: str,
    priority: int,
    action: str,
    name: str,
    block_response: str = None,
    block_override_domain: str = None,
    block_override_dns_type: str = None,
    block_override_ttl: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a single DNS Firewall rule in the specified rule group, using the specified domain list.

    Args:
        creator_request_id(str): A unique string that identifies the request and that allows you to retry failed requests without the risk of running the operation twice. CreatorRequestId can be any unique string, for example, a date/time stamp. .
        firewall_rule_group_id(str): The unique identifier of the firewall rule group where you want to create the rule. .
        firewall_domain_list_id(str): The ID of the domain list that you want to use in the rule. .
        priority(int): The setting that determines the processing order of the rule in the rule group. DNS Firewall processes the rules in a rule group by order of priority, starting from the lowest setting. You must specify a unique priority for each rule in a rule group. To make it easier to insert rules later, leave space between the numbers, for example, use 100, 200, and so on. You can change the priority setting for the rules in a rule group at any time.
        action(str): The action that DNS Firewall should take on a DNS query when it matches one of the domains in the rule's domain list:    ALLOW - Permit the request to go through.    ALERT - Permit the request and send metrics and logs to Cloud Watch.    BLOCK - Disallow the request. This option requires additional details in the rule's BlockResponse.   .
        block_response(str, optional): The way that you want DNS Firewall to block the request, used with the rule action setting BLOCK.     NODATA - Respond indicating that the query was successful, but no response is available for it.    NXDOMAIN - Respond indicating that the domain name that's in the query doesn't exist.    OVERRIDE - Provide a custom override in the response. This option requires custom handling details in the rule's BlockOverride* settings.    This setting is required if the rule action setting is BLOCK. Defaults to None.
        block_override_domain(str, optional): The custom DNS record to send back in response to the query. Used for the rule action BLOCK with a BlockResponse setting of OVERRIDE. This setting is required if the BlockResponse setting is OVERRIDE. Defaults to None.
        block_override_dns_type(str, optional): The DNS record's type. This determines the format of the record value that you provided in BlockOverrideDomain. Used for the rule action BLOCK with a BlockResponse setting of OVERRIDE. This setting is required if the BlockResponse setting is OVERRIDE. Defaults to None.
        block_override_ttl(int, optional): The recommended amount of time, in seconds, for the DNS resolver or web browser to cache the provided override record. Used for the rule action BLOCK with a BlockResponse setting of OVERRIDE. This setting is required if the BlockResponse setting is OVERRIDE. Defaults to None.
        name(str): A name that lets you identify the rule in the rule group.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53resolver.firewall.rule.init.create(
                ctx,
                creator_request_id=value,
                firewall_rule_group_id=value,
                firewall_domain_list_id=value,
                priority=value,
                action=value,
                name=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53resolver.firewall.rule.init.create creator_request_id=value, firewall_rule_group_id=value, firewall_domain_list_id=value, priority=value, action=value, name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53resolver",
        operation="create_firewall_rule",
        op_kwargs={
            "CreatorRequestId": creator_request_id,
            "FirewallRuleGroupId": firewall_rule_group_id,
            "FirewallDomainListId": firewall_domain_list_id,
            "Priority": priority,
            "Action": action,
            "BlockResponse": block_response,
            "BlockOverrideDomain": block_override_domain,
            "BlockOverrideDnsType": block_override_dns_type,
            "BlockOverrideTtl": block_override_ttl,
            "Name": name,
        },
    )


async def delete(
    hub, ctx, firewall_rule_group_id: str, firewall_domain_list_id: str
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified firewall rule.

    Args:
        firewall_rule_group_id(str): The unique identifier of the firewall rule group that you want to delete the rule from. .
        firewall_domain_list_id(str): The ID of the domain list that's used in the rule. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53resolver.firewall.rule.init.delete(
                ctx, firewall_rule_group_id=value, firewall_domain_list_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53resolver.firewall.rule.init.delete firewall_rule_group_id=value, firewall_domain_list_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53resolver",
        operation="delete_firewall_rule",
        op_kwargs={
            "FirewallRuleGroupId": firewall_rule_group_id,
            "FirewallDomainListId": firewall_domain_list_id,
        },
    )


async def list_all(
    hub,
    ctx,
    firewall_rule_group_id: str,
    priority: int = None,
    action: str = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the firewall rules that you have defined for the specified firewall rule group. DNS Firewall uses the rules in a rule group to filter DNS network traffic for a VPC.  A single call might return only a partial list of the rules. For information, see MaxResults.

    Args:
        firewall_rule_group_id(str): The unique identifier of the firewall rule group that you want to retrieve the rules for. .
        priority(int, optional): Optional additional filter for the rules to retrieve. The setting that determines the processing order of the rules in a rule group. DNS Firewall processes the rules in a rule group by order of priority, starting from the lowest setting. Defaults to None.
        action(str, optional): Optional additional filter for the rules to retrieve. The action that DNS Firewall should take on a DNS query when it matches one of the domains in the rule's domain list:    ALLOW - Permit the request to go through.    ALERT - Permit the request to go through but send an alert to the logs.    BLOCK - Disallow the request. If this is specified, additional handling details are provided in the rule's BlockResponse setting.   . Defaults to None.
        max_results(int, optional): The maximum number of objects that you want Resolver to return for this request. If more objects are available, in the response, Resolver provides a NextToken value that you can use in a subsequent call to get the next batch of objects. If you don't specify a value for MaxResults, Resolver returns up to 100 objects. . Defaults to None.
        next_token(str, optional): For the first call to this list request, omit this value. When you request a list of objects, Resolver returns at most the number of objects specified in MaxResults. If more objects are available for retrieval, Resolver returns a NextToken value in the response. To retrieve the next batch of objects, use the token that was returned for the prior request in your next request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53resolver.firewall.rule.init.list_all(
                ctx, firewall_rule_group_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53resolver.firewall.rule.init.list_all firewall_rule_group_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53resolver",
        operation="list_firewall_rules",
        op_kwargs={
            "FirewallRuleGroupId": firewall_rule_group_id,
            "Priority": priority,
            "Action": action,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )


async def update(
    hub,
    ctx,
    firewall_rule_group_id: str,
    firewall_domain_list_id: str,
    priority: int = None,
    action: str = None,
    block_response: str = None,
    block_override_domain: str = None,
    block_override_dns_type: str = None,
    block_override_ttl: int = None,
    name: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the specified firewall rule.

    Args:
        firewall_rule_group_id(str): The unique identifier of the firewall rule group for the rule. .
        firewall_domain_list_id(str): The ID of the domain list to use in the rule. .
        priority(int, optional): The setting that determines the processing order of the rule in the rule group. DNS Firewall processes the rules in a rule group by order of priority, starting from the lowest setting. You must specify a unique priority for each rule in a rule group. To make it easier to insert rules later, leave space between the numbers, for example, use 100, 200, and so on. You can change the priority setting for the rules in a rule group at any time. Defaults to None.
        action(str, optional): The action that DNS Firewall should take on a DNS query when it matches one of the domains in the rule's domain list:    ALLOW - Permit the request to go through.    ALERT - Permit the request to go through but send an alert to the logs.    BLOCK - Disallow the request. This option requires additional details in the rule's BlockResponse.   . Defaults to None.
        block_response(str, optional): The way that you want DNS Firewall to block the request. Used for the rule action setting BLOCK.    NODATA - Respond indicating that the query was successful, but no response is available for it.    NXDOMAIN - Respond indicating that the domain name that's in the query doesn't exist.    OVERRIDE - Provide a custom override in the response. This option requires custom handling details in the rule's BlockOverride* settings.   . Defaults to None.
        block_override_domain(str, optional): The custom DNS record to send back in response to the query. Used for the rule action BLOCK with a BlockResponse setting of OVERRIDE. Defaults to None.
        block_override_dns_type(str, optional): The DNS record's type. This determines the format of the record value that you provided in BlockOverrideDomain. Used for the rule action BLOCK with a BlockResponse setting of OVERRIDE. Defaults to None.
        block_override_ttl(int, optional): The recommended amount of time, in seconds, for the DNS resolver or web browser to cache the provided override record. Used for the rule action BLOCK with a BlockResponse setting of OVERRIDE. Defaults to None.
        name(str, optional): The name of the rule. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53resolver.firewall.rule.init.update(
                ctx, firewall_rule_group_id=value, firewall_domain_list_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53resolver.firewall.rule.init.update firewall_rule_group_id=value, firewall_domain_list_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53resolver",
        operation="update_firewall_rule",
        op_kwargs={
            "FirewallRuleGroupId": firewall_rule_group_id,
            "FirewallDomainListId": firewall_domain_list_id,
            "Priority": priority,
            "Action": action,
            "BlockResponse": block_response,
            "BlockOverrideDomain": block_override_domain,
            "BlockOverrideDnsType": block_override_dns_type,
            "BlockOverrideTtl": block_override_ttl,
            "Name": name,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    user_name: str,
    authentication_type: str,
    message_action: str = None,
    first_name: str = None,
    last_name: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new user in the user pool.

    Args:
        user_name(str): The email address of the user.  Users' email addresses are case-sensitive. During login, if they specify an email address that doesn't use the same capitalization as the email address specified when their user pool account was created, a "user does not exist" error message displays. .
        message_action(str, optional): The action to take for the welcome email that is sent to a user after the user is created in the user pool. If you specify SUPPRESS, no email is sent. If you specify RESEND, do not specify the first name or last name of the user. If the value is null, the email is sent.   The temporary password in the welcome email is valid for only 7 days. If users don’t set their passwords within 7 days, you must send them a new welcome email. . Defaults to None.
        first_name(str, optional): The first name, or given name, of the user. Defaults to None.
        last_name(str, optional): The last name, or surname, of the user. Defaults to None.
        authentication_type(str): The authentication type for the user. You must specify USERPOOL. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appstream.user.init.create(
                ctx, user_name=value, authentication_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appstream.user.init.create user_name=value, authentication_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appstream",
        operation="create_user",
        op_kwargs={
            "UserName": user_name,
            "MessageAction": message_action,
            "FirstName": first_name,
            "LastName": last_name,
            "AuthenticationType": authentication_type,
        },
    )


async def delete(hub, ctx, user_name: str, authentication_type: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a user from the user pool.

    Args:
        user_name(str): The email address of the user.  Users' email addresses are case-sensitive. .
        authentication_type(str): The authentication type for the user. You must specify USERPOOL.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appstream.user.init.delete(
                ctx, user_name=value, authentication_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appstream.user.init.delete user_name=value, authentication_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appstream",
        operation="delete_user",
        op_kwargs={"UserName": user_name, "AuthenticationType": authentication_type},
    )


async def describe_all(
    hub, ctx, authentication_type: str, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a list that describes one or more specified users in the user pool.

    Args:
        authentication_type(str): The authentication type for the users in the user pool to describe. You must specify USERPOOL.
        max_results(int, optional): The maximum size of each page of results. Defaults to None.
        next_token(str, optional): The pagination token to use to retrieve the next page of results for this operation. If this value is null, it retrieves the first page. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appstream.user.init.describe_all(ctx, authentication_type=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appstream.user.init.describe_all authentication_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appstream",
        operation="describe_users",
        op_kwargs={
            "AuthenticationType": authentication_type,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )


async def disable(hub, ctx, user_name: str, authentication_type: str) -> Dict:
    r"""
    **Autogenerated function**

    Disables the specified user in the user pool. Users can't sign in to AppStream 2.0 until they are re-enabled. This action does not delete the user.

    Args:
        user_name(str): The email address of the user.  Users' email addresses are case-sensitive. .
        authentication_type(str): The authentication type for the user. You must specify USERPOOL.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appstream.user.init.disable(
                ctx, user_name=value, authentication_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appstream.user.init.disable user_name=value, authentication_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appstream",
        operation="disable_user",
        op_kwargs={"UserName": user_name, "AuthenticationType": authentication_type},
    )


async def enable(hub, ctx, user_name: str, authentication_type: str) -> Dict:
    r"""
    **Autogenerated function**

    Enables a user in the user pool. After being enabled, users can sign in to AppStream 2.0 and open applications from the stacks to which they are assigned.

    Args:
        user_name(str): The email address of the user.  Users' email addresses are case-sensitive. During login, if they specify an email address that doesn't use the same capitalization as the email address specified when their user pool account was created, a "user does not exist" error message displays.  .
        authentication_type(str): The authentication type for the user. You must specify USERPOOL.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appstream.user.init.enable(
                ctx, user_name=value, authentication_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appstream.user.init.enable user_name=value, authentication_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appstream",
        operation="enable_user",
        op_kwargs={"UserName": user_name, "AuthenticationType": authentication_type},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def put(
    hub,
    ctx,
    metadata_key_value: Dict,
    schema_id: Dict = None,
    schema_version_number: Dict = None,
    schema_version_id: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Puts the metadata key value pair for a specified schema version ID. A maximum of 10 key value pairs will be allowed per schema version. They can be added over one or more calls.

    Args:
        schema_id(Dict, optional): The unique ID for the schema. Defaults to None.
        schema_version_number(Dict, optional): The version number of the schema. Defaults to None.
        schema_version_id(str, optional): The unique version ID of the schema version. Defaults to None.
        metadata_key_value(Dict): The metadata key's corresponding value.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.schema.version.metadata.put(ctx, metadata_key_value=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.schema.version.metadata.put metadata_key_value=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="put_schema_version_metadata",
        op_kwargs={
            "SchemaId": schema_id,
            "SchemaVersionNumber": schema_version_number,
            "SchemaVersionId": schema_version_id,
            "MetadataKeyValue": metadata_key_value,
        },
    )


async def query(
    hub,
    ctx,
    schema_id: Dict = None,
    schema_version_number: Dict = None,
    schema_version_id: str = None,
    metadata_list: List = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Queries for the schema version metadata information.

    Args:
        schema_id(Dict, optional): A wrapper structure that may contain the schema name and Amazon Resource Name (ARN). Defaults to None.
        schema_version_number(Dict, optional): The version number of the schema. Defaults to None.
        schema_version_id(str, optional): The unique version ID of the schema version. Defaults to None.
        metadata_list(List, optional): Search key-value pairs for metadata, if they are not provided all the metadata information will be fetched. Defaults to None.
        max_results(int, optional): Maximum number of results required per page. If the value is not supplied, this will be defaulted to 25 per page. Defaults to None.
        next_token(str, optional): A continuation token, if this is a continuation call. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.schema.version.metadata.query(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.schema.version.metadata.query
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="query_schema_version_metadata",
        op_kwargs={
            "SchemaId": schema_id,
            "SchemaVersionNumber": schema_version_number,
            "SchemaVersionId": schema_version_id,
            "MetadataList": metadata_list,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )


async def remove(
    hub,
    ctx,
    metadata_key_value: Dict,
    schema_id: Dict = None,
    schema_version_number: Dict = None,
    schema_version_id: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Removes a key value pair from the schema version metadata for the specified schema version ID.

    Args:
        schema_id(Dict, optional): A wrapper structure that may contain the schema name and Amazon Resource Name (ARN). Defaults to None.
        schema_version_number(Dict, optional): The version number of the schema. Defaults to None.
        schema_version_id(str, optional): The unique version ID of the schema version. Defaults to None.
        metadata_key_value(Dict): The value of the metadata key.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.schema.version.metadata.remove(
                ctx, metadata_key_value=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.schema.version.metadata.remove metadata_key_value=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="remove_schema_version_metadata",
        op_kwargs={
            "SchemaId": schema_id,
            "SchemaVersionNumber": schema_version_number,
            "SchemaVersionId": schema_version_id,
            "MetadataKeyValue": metadata_key_value,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def delete(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Permanently deletes the metric stream that you specify.

    Args:
        name(str): The name of the metric stream to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudwatch.metric.stream.delete(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudwatch.metric.stream.delete name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudwatch",
        operation="delete_metric_stream",
        op_kwargs={"Name": name},
    )


async def get(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about the metric stream that you specify.

    Args:
        name(str): The name of the metric stream to retrieve information about.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudwatch.metric.stream.get(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudwatch.metric.stream.get name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudwatch",
        operation="get_metric_stream",
        op_kwargs={"Name": name},
    )


async def list_all(hub, ctx, next_token: str = None, max_results: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of metric streams in this account.

    Args:
        next_token(str, optional): Include this value, if it was returned by the previous call, to get the next set of metric streams. Defaults to None.
        max_results(int, optional): The maximum number of results to return in one operation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudwatch.metric.stream.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudwatch.metric.stream.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudwatch",
        operation="list_metric_streams",
        op_kwargs={"NextToken": next_token, "MaxResults": max_results},
    )


async def put(
    hub,
    ctx,
    name: str,
    firehose_arn: str,
    role_arn: str,
    output_format: str,
    include_filters: List = None,
    exclude_filters: List = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates or updates a metric stream. Metric streams can automatically stream CloudWatch metrics to Amazon Web Services destinations including Amazon S3 and to many third-party solutions. For more information, see  Using Metric Streams. To create a metric stream, you must be logged on to an account that has the iam:PassRole permission and either the CloudWatchFullAccess policy or the cloudwatch:PutMetricStream permission. When you create or update a metric stream, you choose one of the following:   Stream metrics from all metric namespaces in the account.   Stream metrics from all metric namespaces in the account, except for the namespaces that you list in ExcludeFilters.   Stream metrics from only the metric namespaces that you list in IncludeFilters.   When you use PutMetricStream to create a new metric stream, the stream is created in the running state. If you use it to update an existing stream, the state of the stream is not changed.

    Args:
        name(str): If you are creating a new metric stream, this is the name for the new stream. The name must be different than the names of other metric streams in this account and Region. If you are updating a metric stream, specify the name of that stream here. Valid characters are A-Z, a-z, 0-9, "-" and "_".
        include_filters(List, optional): If you specify this parameter, the stream sends only the metrics from the metric namespaces that you specify here. You cannot include IncludeFilters and ExcludeFilters in the same operation. Defaults to None.
        exclude_filters(List, optional): If you specify this parameter, the stream sends metrics from all metric namespaces except for the namespaces that you specify here. You cannot include ExcludeFilters and IncludeFilters in the same operation. Defaults to None.
        firehose_arn(str): The ARN of the Amazon Kinesis Firehose delivery stream to use for this metric stream. This Amazon Kinesis Firehose delivery stream must already exist and must be in the same account as the metric stream.
        role_arn(str): The ARN of an IAM role that this metric stream will use to access Amazon Kinesis Firehose resources. This IAM role must already exist and must be in the same account as the metric stream. This IAM role must include the following permissions:   firehose:PutRecord   firehose:PutRecordBatch  .
        output_format(str): The output format for the stream. Valid values are json and opentelemetry0.7. For more information about metric stream output formats, see  Metric streams output formats.
        tags(List, optional): A list of key-value pairs to associate with the metric stream. You can associate as many as 50 tags with a metric stream. Tags can help you organize and categorize your resources. You can also use them to scope user permissions by granting a user permission to access or change only resources with certain tag values. You can use this parameter only when you are creating a new metric stream. If you are using this operation to update an existing metric stream, any tags you specify in this parameter are ignored. To change the tags of an existing metric stream, use TagResource or UntagResource. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudwatch.metric.stream.put(
                ctx, name=value, firehose_arn=value, role_arn=value, output_format=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudwatch.metric.stream.put name=value, firehose_arn=value, role_arn=value, output_format=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudwatch",
        operation="put_metric_stream",
        op_kwargs={
            "Name": name,
            "IncludeFilters": include_filters,
            "ExcludeFilters": exclude_filters,
            "FirehoseArn": firehose_arn,
            "RoleArn": role_arn,
            "OutputFormat": output_format,
            "Tags": tags,
        },
    )


async def start(hub, ctx, names: List) -> Dict:
    r"""
    **Autogenerated function**

    Starts the streaming of metrics for one or more of your metric streams.

    Args:
        names(List): The array of the names of metric streams to start streaming. This is an "all or nothing" operation. If you do not have permission to access all of the metric streams that you list here, then none of the streams that you list in the operation will start streaming.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudwatch.metric.stream.start(ctx, names=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudwatch.metric.stream.start names=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudwatch",
        operation="start_metric_streams",
        op_kwargs={"Names": names},
    )


async def stop(hub, ctx, names: List) -> Dict:
    r"""
    **Autogenerated function**

    Stops the streaming of metrics for one or more of your metric streams.

    Args:
        names(List): The array of the names of metric streams to stop streaming. This is an "all or nothing" operation. If you do not have permission to access all of the metric streams that you list here, then none of the streams that you list in the operation will stop streaming.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudwatch.metric.stream.stop(ctx, names=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudwatch.metric.stream.stop names=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudwatch",
        operation="stop_metric_streams",
        op_kwargs={"Names": names},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def delete(hub, ctx, rest_api_id: str, response_type: str) -> None:
    r"""
    **Autogenerated function**

    Clears any customization of a GatewayResponse of a specified response type on the given RestApi and resets it with the default settings.

    Args:
        rest_api_id(str): [Required] The string identifier of the associated RestApi.
        response_type(str): [Required] The response type of the associated GatewayResponse. Valid values are ACCESS_DENIEDAPI_CONFIGURATION_ERRORAUTHORIZER_FAILURE AUTHORIZER_CONFIGURATION_ERRORBAD_REQUEST_PARAMETERSBAD_REQUEST_BODYDEFAULT_4XXDEFAULT_5XXEXPIRED_TOKENINVALID_SIGNATUREINTEGRATION_FAILUREINTEGRATION_TIMEOUTINVALID_API_KEYMISSING_AUTHENTICATION_TOKEN QUOTA_EXCEEDEDREQUEST_TOO_LARGERESOURCE_NOT_FOUNDTHROTTLEDUNAUTHORIZEDUNSUPPORTED_MEDIA_TYPE .
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.gateway_response.delete(
                ctx, rest_api_id=value, response_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.gateway_response.delete rest_api_id=value, response_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="delete_gateway_response",
        op_kwargs={"restApiId": rest_api_id, "responseType": response_type},
    )


async def get(hub, ctx, rest_api_id: str, response_type: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets a GatewayResponse of a specified response type on the given RestApi.

    Args:
        rest_api_id(str): [Required] The string identifier of the associated RestApi.
        response_type(str): [Required] The response type of the associated GatewayResponse. Valid values are ACCESS_DENIEDAPI_CONFIGURATION_ERRORAUTHORIZER_FAILURE AUTHORIZER_CONFIGURATION_ERRORBAD_REQUEST_PARAMETERSBAD_REQUEST_BODYDEFAULT_4XXDEFAULT_5XXEXPIRED_TOKENINVALID_SIGNATUREINTEGRATION_FAILUREINTEGRATION_TIMEOUTINVALID_API_KEYMISSING_AUTHENTICATION_TOKEN QUOTA_EXCEEDEDREQUEST_TOO_LARGERESOURCE_NOT_FOUNDTHROTTLEDUNAUTHORIZEDUNSUPPORTED_MEDIA_TYPE .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.gateway_response.get(
                ctx, rest_api_id=value, response_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.gateway_response.get rest_api_id=value, response_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="get_gateway_response",
        op_kwargs={"restApiId": rest_api_id, "responseType": response_type},
    )


async def get_all(
    hub, ctx, rest_api_id: str, position: str = None, limit: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Gets the GatewayResponses collection on the given RestApi. If an API developer has not added any definitions for gateway responses, the result will be the API Gateway-generated default GatewayResponses collection for the supported response types.

    Args:
        rest_api_id(str): [Required] The string identifier of the associated RestApi.
        position(str, optional): The current pagination position in the paged result set. The GatewayResponse collection does not support pagination and the position does not apply here. Defaults to None.
        limit(int, optional): The maximum number of returned results per page. The default value is 25 and the maximum value is 500. The GatewayResponses collection does not support pagination and the limit does not apply here. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.gateway_response.get_all(ctx, rest_api_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.gateway_response.get_all rest_api_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="get_gateway_responses",
        op_kwargs={"restApiId": rest_api_id, "position": position, "limit": limit},
    )


async def put(
    hub,
    ctx,
    rest_api_id: str,
    response_type: str,
    status_code: str = None,
    response_parameters: Dict = None,
    response_templates: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a customization of a GatewayResponse of a specified response type and status code on the given RestApi.

    Args:
        rest_api_id(str): [Required] The string identifier of the associated RestApi.
        response_type(str): [Required] The response type of the associated GatewayResponse. Valid values are ACCESS_DENIEDAPI_CONFIGURATION_ERRORAUTHORIZER_FAILURE AUTHORIZER_CONFIGURATION_ERRORBAD_REQUEST_PARAMETERSBAD_REQUEST_BODYDEFAULT_4XXDEFAULT_5XXEXPIRED_TOKENINVALID_SIGNATUREINTEGRATION_FAILUREINTEGRATION_TIMEOUTINVALID_API_KEYMISSING_AUTHENTICATION_TOKEN QUOTA_EXCEEDEDREQUEST_TOO_LARGERESOURCE_NOT_FOUNDTHROTTLEDUNAUTHORIZEDUNSUPPORTED_MEDIA_TYPE .
        status_code(str, optional): The HTTP status code of the GatewayResponse. Defaults to None.
        response_parameters(Dict, optional): Response parameters (paths, query strings and headers) of the GatewayResponse as a string-to-string map of key-value pairs. Defaults to None.
        response_templates(Dict, optional): Response templates of the GatewayResponse as a string-to-string map of key-value pairs. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.gateway_response.put(
                ctx, rest_api_id=value, response_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.gateway_response.put rest_api_id=value, response_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="put_gateway_response",
        op_kwargs={
            "restApiId": rest_api_id,
            "responseType": response_type,
            "statusCode": status_code,
            "responseParameters": response_parameters,
            "responseTemplates": response_templates,
        },
    )


async def update(
    hub, ctx, rest_api_id: str, response_type: str, patch_operations: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Updates a GatewayResponse of a specified response type on the given RestApi.

    Args:
        rest_api_id(str): [Required] The string identifier of the associated RestApi.
        response_type(str): [Required] The response type of the associated GatewayResponse. Valid values are ACCESS_DENIEDAPI_CONFIGURATION_ERRORAUTHORIZER_FAILURE AUTHORIZER_CONFIGURATION_ERRORBAD_REQUEST_PARAMETERSBAD_REQUEST_BODYDEFAULT_4XXDEFAULT_5XXEXPIRED_TOKENINVALID_SIGNATUREINTEGRATION_FAILUREINTEGRATION_TIMEOUTINVALID_API_KEYMISSING_AUTHENTICATION_TOKEN QUOTA_EXCEEDEDREQUEST_TOO_LARGERESOURCE_NOT_FOUNDTHROTTLEDUNAUTHORIZEDUNSUPPORTED_MEDIA_TYPE .
        patch_operations(List, optional): A list of update operations to be applied to the specified resource and in the order specified in this list. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.gateway_response.update(
                ctx, rest_api_id=value, response_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.gateway_response.update rest_api_id=value, response_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="update_gateway_response",
        op_kwargs={
            "restApiId": rest_api_id,
            "responseType": response_type,
            "patchOperations": patch_operations,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    vpce_configuration_name: str,
    vpce_service_name: str,
    service_dns_name: str,
    vpce_configuration_description: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a configuration record in Device Farm for your Amazon Virtual Private Cloud (VPC) endpoint.

    Args:
        vpce_configuration_name(str): The friendly name you give to your VPC endpoint configuration, to manage your configurations more easily.
        vpce_service_name(str): The name of the VPC endpoint service running in your AWS account that you want Device Farm to test.
        service_dns_name(str): The DNS name of the service running in your VPC that you want Device Farm to test.
        vpce_configuration_description(str, optional): An optional description that provides details about your VPC endpoint configuration. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.devicefarm.vpce_configuration.create(
                ctx, vpce_configuration_name=value, vpce_service_name=value, service_dns_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.devicefarm.vpce_configuration.create vpce_configuration_name=value, vpce_service_name=value, service_dns_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="devicefarm",
        operation="create_vpce_configuration",
        op_kwargs={
            "vpceConfigurationName": vpce_configuration_name,
            "vpceServiceName": vpce_service_name,
            "serviceDnsName": service_dns_name,
            "vpceConfigurationDescription": vpce_configuration_description,
        },
    )


async def delete(hub, ctx, arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a configuration for your Amazon Virtual Private Cloud (VPC) endpoint.

    Args:
        arn(str): The Amazon Resource Name (ARN) of the VPC endpoint configuration you want to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.devicefarm.vpce_configuration.delete(ctx, arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.devicefarm.vpce_configuration.delete arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="devicefarm",
        operation="delete_vpce_configuration",
        op_kwargs={"arn": arn},
    )


async def get(hub, ctx, arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about the configuration settings for your Amazon Virtual Private Cloud (VPC) endpoint.

    Args:
        arn(str): The Amazon Resource Name (ARN) of the VPC endpoint configuration you want to describe.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.devicefarm.vpce_configuration.get(ctx, arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.devicefarm.vpce_configuration.get arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="devicefarm",
        operation="get_vpce_configuration",
        op_kwargs={"arn": arn},
    )


async def list_all(hub, ctx, max_results: int = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about all Amazon Virtual Private Cloud (VPC) endpoint configurations in the AWS account.

    Args:
        max_results(int, optional): An integer that specifies the maximum number of items you want to return in the API response. Defaults to None.
        next_token(str, optional): An identifier that was returned from the previous call to this operation, which can be used to return the next set of items in the list. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.devicefarm.vpce_configuration.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.devicefarm.vpce_configuration.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="devicefarm",
        operation="list_vpce_configurations",
        op_kwargs={"maxResults": max_results, "nextToken": next_token},
    )


async def update(
    hub,
    ctx,
    arn: str,
    vpce_configuration_name: str = None,
    vpce_service_name: str = None,
    service_dns_name: str = None,
    vpce_configuration_description: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates information about an Amazon Virtual Private Cloud (VPC) endpoint configuration.

    Args:
        arn(str): The Amazon Resource Name (ARN) of the VPC endpoint configuration you want to update.
        vpce_configuration_name(str, optional): The friendly name you give to your VPC endpoint configuration to manage your configurations more easily. Defaults to None.
        vpce_service_name(str, optional): The name of the VPC endpoint service running in your AWS account that you want Device Farm to test. Defaults to None.
        service_dns_name(str, optional): The DNS (domain) name used to connect to your private service in your VPC. The DNS name must not already be in use on the internet. Defaults to None.
        vpce_configuration_description(str, optional): An optional description that provides details about your VPC endpoint configuration. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.devicefarm.vpce_configuration.update(ctx, arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.devicefarm.vpce_configuration.update arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="devicefarm",
        operation="update_vpce_configuration",
        op_kwargs={
            "arn": arn,
            "vpceConfigurationName": vpce_configuration_name,
            "vpceServiceName": vpce_service_name,
            "serviceDnsName": service_dns_name,
            "vpceConfigurationDescription": vpce_configuration_description,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def generate(hub, ctx, arn: str, granularity: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Generates a report that includes details about when an IAM resource (user, group, role, or policy) was last used in an attempt to access Amazon Web Services services. Recent activity usually appears within four hours. IAM reports activity for the last 365 days, or less if your Region began supporting this feature within the last year. For more information, see Regions where data is tracked.  The service last accessed data includes all attempts to access an Amazon Web Services API, not just the successful ones. This includes all attempts that were made using the Management Console, the Amazon Web Services API through any of the SDKs, or any of the command line tools. An unexpected entry in the service last accessed data does not mean that your account has been compromised, because the request might have been denied. Refer to your CloudTrail logs as the authoritative source for information about all API calls and whether they were successful or denied access. For more information, see Logging IAM events with CloudTrail in the IAM User Guide.  The GenerateServiceLastAccessedDetails operation returns a JobId. Use this parameter in the following operations to retrieve the following details from your report:     GetServiceLastAccessedDetails – Use this operation for users, groups, roles, or policies to list every Amazon Web Services service that the resource could access using permissions policies. For each service, the response includes information about the most recent access attempt. The JobId returned by GenerateServiceLastAccessedDetail must be used by the same role within a session, or by the same user when used to call GetServiceLastAccessedDetail.    GetServiceLastAccessedDetailsWithEntities – Use this operation for groups and policies to list information about the associated entities (users or roles) that attempted to access a specific Amazon Web Services service.    To check the status of the GenerateServiceLastAccessedDetails request, use the JobId parameter in the same operations and test the JobStatus response parameter. For additional information about the permissions policies that allow an identity (user, group, or role) to access specific services, use the ListPoliciesGrantingServiceAccess operation.  Service last accessed data does not use other policy types when determining whether a resource could access a service. These other policy types include resource-based policies, access control lists, Organizations policies, IAM permissions boundaries, and STS assume role policies. It only applies permissions policy logic. For more about the evaluation of policy types, see Evaluating policies in the IAM User Guide.  For more information about service and action last accessed data, see Reducing permissions using service last accessed data in the IAM User Guide.

    Args:
        arn(str): The ARN of the IAM resource (user, group, role, or managed policy) used to generate information about when the resource was last used in an attempt to access an Amazon Web Services service.
        granularity(str, optional): The level of detail that you want to generate. You can specify whether you want to generate information about the last attempt to access services or actions. If you specify service-level granularity, this operation generates only service data. If you specify action-level granularity, it generates service and action data. If you don't include this optional parameter, the operation generates service data. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.service.last_accessed_detail.init.generate(ctx, arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.service.last_accessed_detail.init.generate arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="generate_service_last_accessed_details",
        op_kwargs={"Arn": arn, "Granularity": granularity},
    )


async def get_all(
    hub, ctx, job_id: str, max_items: int = None, marker: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a service last accessed report that was created using the GenerateServiceLastAccessedDetails operation. You can use the JobId parameter in GetServiceLastAccessedDetails to retrieve the status of your report job. When the report is complete, you can retrieve the generated report. The report includes a list of Amazon Web Services services that the resource (user, group, role, or managed policy) can access.  Service last accessed data does not use other policy types when determining whether a resource could access a service. These other policy types include resource-based policies, access control lists, Organizations policies, IAM permissions boundaries, and STS assume role policies. It only applies permissions policy logic. For more about the evaluation of policy types, see Evaluating policies in the IAM User Guide.  For each service that the resource could access using permissions policies, the operation returns details about the most recent access attempt. If there was no attempt, the service is listed without details about the most recent attempt to access the service. If the operation fails, the GetServiceLastAccessedDetails operation returns the reason that it failed. The GetServiceLastAccessedDetails operation returns a list of services. This list includes the number of entities that have attempted to access the service and the date and time of the last attempt. It also returns the ARN of the following entity, depending on the resource ARN that you used to generate the report:    User – Returns the user ARN that you used to generate the report    Group – Returns the ARN of the group member (user) that last attempted to access the service    Role – Returns the role ARN that you used to generate the report    Policy – Returns the ARN of the user or role that last used the policy to attempt to access the service   By default, the list is sorted by service namespace. If you specified ACTION_LEVEL granularity when you generated the report, this operation returns service and action last accessed data. This includes the most recent access attempt for each tracked action within a service. Otherwise, this operation returns only service data. For more information about service and action last accessed data, see Reducing permissions using service last accessed data in the IAM User Guide.

    Args:
        job_id(str): The ID of the request generated by the GenerateServiceLastAccessedDetails operation. The JobId returned by GenerateServiceLastAccessedDetail must be used by the same role within a session, or by the same user when used to call GetServiceLastAccessedDetail.
        max_items(int, optional): Use this only when paginating results to indicate the maximum number of items you want in the response. If additional items exist beyond the maximum you specify, the IsTruncated response element is true. If you do not include this parameter, the number of items defaults to 100. Note that IAM might return fewer results, even when there are more results available. In that case, the IsTruncated response element returns true, and Marker contains a value to include in the subsequent call that tells the service where to continue from. Defaults to None.
        marker(str, optional): Use this parameter only when paginating results and only after you receive a response indicating that the results are truncated. Set it to the value of the Marker element in the response that you received to indicate where the next call should start. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.service.last_accessed_detail.init.get_all(ctx, job_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.service.last_accessed_detail.init.get_all job_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="get_service_last_accessed_details",
        op_kwargs={"JobId": job_id, "MaxItems": max_items, "Marker": marker},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe_all(hub, ctx, aws_account_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes the settings that were used when your QuickSight subscription was first created in this Amazon Web Services account;.

    Args:
        aws_account_id(str): The ID for the Amazon Web Services account; that contains the settings that you want to list.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.quicksight.account.setting.describe_all(
                ctx, aws_account_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.quicksight.account.setting.describe_all aws_account_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="quicksight",
        operation="describe_account_settings",
        op_kwargs={"AwsAccountId": aws_account_id},
    )


async def update_multiple(
    hub,
    ctx,
    aws_account_id: str,
    default_namespace: str,
    notification_email: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the Amazon QuickSight settings in your Amazon Web Services account;.

    Args:
        aws_account_id(str): The ID for the Amazon Web Services account; that contains the QuickSight settings that you want to list.
        default_namespace(str): The default namespace for this Amazon Web Services account;. Currently, the default is default. Identity and Access Management (IAM) users that register for the first time with QuickSight provide an email that becomes associated with the default namespace.
        notification_email(str, optional): The email address that you want QuickSight to send notifications to regarding your Amazon Web Services account; or QuickSight subscription. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.quicksight.account.setting.update_multiple(
                ctx, aws_account_id=value, default_namespace=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.quicksight.account.setting.update_multiple aws_account_id=value, default_namespace=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="quicksight",
        operation="update_account_settings",
        op_kwargs={
            "AwsAccountId": aws_account_id,
            "DefaultNamespace": default_namespace,
            "NotificationEmail": notification_email,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def associate(hub, ctx, assessment_id: str, evidence_folder_id: str) -> Dict:
    r"""
    **Autogenerated function**

     Associates an evidence folder to the specified assessment report in Audit Manager.

    Args:
        assessment_id(str):  The identifier for the specified assessment. .
        evidence_folder_id(str):  The identifier for the folder in which evidence is stored. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.auditmanager.assessment.report.evidence_folder.associate(
                ctx, assessment_id=value, evidence_folder_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.auditmanager.assessment.report.evidence_folder.associate assessment_id=value, evidence_folder_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="auditmanager",
        operation="associate_assessment_report_evidence_folder",
        op_kwargs={
            "assessmentId": assessment_id,
            "evidenceFolderId": evidence_folder_id,
        },
    )


async def disassociate(hub, ctx, assessment_id: str, evidence_folder_id: str) -> Dict:
    r"""
    **Autogenerated function**

     Disassociates an evidence folder from the specified assessment report in Audit Manager.

    Args:
        assessment_id(str):  The identifier for the specified assessment. .
        evidence_folder_id(str):  The identifier for the folder in which evidence is stored. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.auditmanager.assessment.report.evidence_folder.disassociate(
                ctx, assessment_id=value, evidence_folder_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.auditmanager.assessment.report.evidence_folder.disassociate assessment_id=value, evidence_folder_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="auditmanager",
        operation="disassociate_assessment_report_evidence_folder",
        op_kwargs={
            "assessmentId": assessment_id,
            "evidenceFolderId": evidence_folder_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""


async def delete(hub, ctx) -> None:
    r"""
    **Autogenerated function**

    Deletes the service-linked role that Elasticsearch Service uses to manage and maintain VPC domains. Role deletion will fail if any existing VPC domains use the role. You must delete any such Elasticsearch domains before deleting the role. See Deleting Elasticsearch Service Role in VPC Endpoints for Amazon Elasticsearch Service Domains.

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.es.elasticsearch.service.role.delete(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.es.elasticsearch.service.role.delete
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="es",
        operation="delete_elasticsearch_service_role",
        op_kwargs={},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def send(
    hub, ctx, channel_arn: str, sender_client_id: str, message_payload: str
) -> Dict:
    r"""
    **Autogenerated function**

    This API allows you to connect WebRTC-enabled devices with Alexa display devices. When invoked, it sends the Alexa Session Description Protocol (SDP) offer to the master peer. The offer is delivered as soon as the master is connected to the specified signaling channel. This API returns the SDP answer from the connected master. If the master is not connected to the signaling channel, redelivery requests are made until the message expires.

    Args:
        channel_arn(str): The ARN of the signaling channel by which Alexa and the master peer communicate.
        sender_client_id(str): The unique identifier for the sender client.
        message_payload(str): The base64-encoded SDP offer content.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kinesis_video_signaling.alexa_offer_to_master.send(
                ctx, channel_arn=value, sender_client_id=value, message_payload=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kinesis_video_signaling.alexa_offer_to_master.send channel_arn=value, sender_client_id=value, message_payload=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kinesis-video-signaling",
        operation="send_alexa_offer_to_master",
        op_kwargs={
            "ChannelARN": channel_arn,
            "SenderClientId": sender_client_id,
            "MessagePayload": message_payload,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def approve(
    hub,
    ctx,
    assignment_id: str,
    requester_feedback: str = None,
    override_rejection: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

     The ApproveAssignment operation approves the results of a completed assignment.   Approving an assignment initiates two payments from the Requester's Amazon.com account     The Worker who submitted the results is paid the reward specified in the HIT.     Amazon Mechanical Turk fees are debited.     If the Requester's account does not have adequate funds for these payments, the call to ApproveAssignment returns an exception, and the approval is not processed. You can include an optional feedback message with the approval, which the Worker can see in the Status section of the web site.   You can also call this operation for assignments that were previous rejected and approve them by explicitly overriding the previous rejection. This only works on rejected assignments that were submitted within the previous 30 days and only if the assignment's related HIT has not been deleted.

    Args:
        assignment_id(str):  The ID of the assignment. The assignment must correspond to a HIT created by the Requester. .
        requester_feedback(str, optional):  A message for the Worker, which the Worker can see in the Status section of the web site. . Defaults to None.
        override_rejection(bool, optional):  A flag indicating that an assignment should be approved even if it was previously rejected. Defaults to False. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mturk.assignment.init.approve(ctx, assignment_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mturk.assignment.init.approve assignment_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mturk",
        operation="approve_assignment",
        op_kwargs={
            "AssignmentId": assignment_id,
            "RequesterFeedback": requester_feedback,
            "OverrideRejection": override_rejection,
        },
    )


async def get(hub, ctx, assignment_id: str) -> Dict:
    r"""
    **Autogenerated function**

     The GetAssignment operation retrieves the details of the specified Assignment.

    Args:
        assignment_id(str): The ID of the Assignment to be retrieved.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mturk.assignment.init.get(ctx, assignment_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mturk.assignment.init.get assignment_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mturk",
        operation="get_assignment",
        op_kwargs={"AssignmentId": assignment_id},
    )


async def reject(hub, ctx, assignment_id: str, requester_feedback: str) -> Dict:
    r"""
    **Autogenerated function**

     The RejectAssignment operation rejects the results of a completed assignment.   You can include an optional feedback message with the rejection, which the Worker can see in the Status section of the web site. When you include a feedback message with the rejection, it helps the Worker understand why the assignment was rejected, and can improve the quality of the results the Worker submits in the future.   Only the Requester who created the HIT can reject an assignment for the HIT.

    Args:
        assignment_id(str):  The ID of the assignment. The assignment must correspond to a HIT created by the Requester. .
        requester_feedback(str):  A message for the Worker, which the Worker can see in the Status section of the web site. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mturk.assignment.init.reject(
                ctx, assignment_id=value, requester_feedback=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mturk.assignment.init.reject assignment_id=value, requester_feedback=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mturk",
        operation="reject_assignment",
        op_kwargs={
            "AssignmentId": assignment_id,
            "RequesterFeedback": requester_feedback,
        },
    )
